@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2011 Stephen Williams (steve@icarus.com)
+ * Copyright (c) 1998-2012 Stephen Williams (steve@icarus.com)
  *
  *    This source code is free software; you can redistribute it
  *    and/or modify it in source code form under the terms of the GNU
@@ -1967,7 +1967,10 @@ void pform_set_specparam(perm_string name, PExpr*expr)
 void pform_set_defparam(const pform_name_t&name, PExpr*expr)
 {
       assert(expr);
-      pform_cur_module->defparms.push_back(make_pair(name,expr));
+      if (pform_cur_generate)
+            pform_cur_generate->defparms.push_back(make_pair(name,expr));
+      else
+            pform_cur_module->defparms.push_back(make_pair(name,expr));
 }
 
 /*
@@ -1979,6 +1982,8 @@ extern PSpecPath* pform_make_specify_path(const struct vlltype&li,
 {
       PSpecPath*path = new PSpecPath(src->size(), dst->size());
       FILE_NAME(path, li.text, li.first_line);
+      path->polarity = pol;
+      path->full_flag = full_flag;
 
       unsigned idx;
       list<perm_string>::const_iterator cur;
